@@ -2,6 +2,35 @@ package t::lib::TestApp;
 
 use Dancer;
 use Dancer::Plugin::Database;
+no warnings 'uninitialized';
+
+hook database_connected => sub {
+    my $dbh = shift;
+    var(connecthookfired => $dbh);
+};
+
+get '/connecthookfired' => sub {
+    my $database = database();
+    # If the hook fired, it'll have squirreled away a reference to the DB handle
+    # for us to look for.
+    my $h = var('connecthookfired');
+    if (ref $h && $h->isa('DBI::db')) {
+        return 1;
+    } else {
+        return 0;
+    }
+};
+
+my $last_db_error;
+hook 'database_error' => sub {
+    $last_db_error = $_[0];
+};
+
+get '/errorhookfired' => sub {
+    database->do('something silly');
+    return $last_db_error ? 1 : 0;
+};
+
 
 get '/prepare_db' => sub {
 
@@ -12,6 +41,8 @@ get '/prepare_db' => sub {
         q/insert into users values (3, 'badger', 'animal')/,
         q/insert into users values (4, 'bodger', 'man')/,
         q/insert into users values (5, 'mousey', 'animal')/,
+        q/insert into users values (6, 'mystery2', null)/,
+        q/insert into users values (7, 'mystery1', null)/,
     );
 
     database->do($_) for @sql;
@@ -133,6 +164,12 @@ get '/quick_select_sorted_rev' => sub {
     );
     return join ':', map { $_->{name} } @users;
 };
+get '/quick_select_sorted_where' => sub {
+    my @users = database->quick_select(
+        'users', { category => undef }, { order_by => 'name' }
+    );
+    return join ':', map { $_->{name} } @users;
+};
 
 
 
@@ -147,4 +184,43 @@ get '/handles_cached' => sub {
     database() eq database() and return "Same handle returned";
 };
 
+
+# Check that the database_connection_lost hook fires when we force a db handle
+# to go away:
+hook database_connection_lost => sub { var(lost_connection => 1); };
+get '/database_connection_lost_fires' => sub {
+    var(lost_connection => 0);
+    database()->disconnect;
+    # We set connection_check_threshold to 0.1 at the start, so wait a second
+    # then check that the code detects the handle is no longer connected and
+    # triggers the hook
+    sleep 1;
+    my $handle = database();
+    return var('lost_connection');
+};
+
+# Check that database_connection_failed hook fires if we can't connect - pass
+# bogus connection details to make that happen
+hook database_connection_failed => sub {
+    var connection_failed => 1;
+};
+get '/database_connection_failed_fires' => sub {
+    # Give a ridiculous database filename which should never exist in order to
+    # force a connection failure
+    my $handle = database({ 
+        dsn => "dbi:SQLite:/Please/Tell/Me/This/File/Does/Not/Exist!",
+        dbi_params => {
+            HandleError => sub { return 0 }, # gobble connect failed message
+            RaiseError => 0,
+            PrintError => 0,
+        },
+    });
+    return var 'connection_failed';
+};
+
+# Check that the handle isa() subclass of the named class
+get '/isa/:class' => sub {
+    return database->isa(params->{class}) ? 1 : 0;
+};
+
 1;
